Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(634)

Unified Diff: chrome/browser/resources/options/content_settings.js

Issue 566063002: Compile chrome://settings, part 8: the final battle (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@H_options_errors_6
Patch Set: rebase Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/options/content_settings.js
diff --git a/chrome/browser/resources/options/content_settings.js b/chrome/browser/resources/options/content_settings.js
index b0b434097e21dd0ad63ca6373240c781396e1465..df2ba0886ad634e1fb0017b9f1401a2d372bee38 100644
--- a/chrome/browser/resources/options/content_settings.js
+++ b/chrome/browser/resources/options/content_settings.js
@@ -2,6 +2,19 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
+cr.exportPath('options');
+
+/**
+ * @typedef {{appId: string,
+ * appName: (string|undefined),
+ * embeddingOrigin: (string|undefined),
+ * origin: string,
+ * setting: string,
+ * source: string,
+ * video: (string|undefined)}}
+ */
+options.Exception;
+
cr.define('options', function() {
/** @const */ var Page = cr.ui.pageManager.Page;
/** @const */ var PageManager = cr.ui.pageManager.PageManager;
@@ -118,8 +131,8 @@ cr.define('options', function() {
/**
* Sets the values for all the content settings radios and labels.
- * @param {Object} dict A mapping from radio groups to the checked value for
- * that group.
+ * @param {Object.<string, {managedBy: string, value: string}>} dict A mapping
+ * from radio groups to the checked value for that group.
*/
ContentSettings.setContentFilterSettingsValue = function(dict) {
for (var group in dict) {
@@ -205,9 +218,9 @@ cr.define('options', function() {
/**
* Initializes an exceptions list.
* @param {string} type The content type that we are setting exceptions for.
* @param {Array} exceptions An array of pairs, where the first element of
* each pair is the filter string, and the second is the setting
* (allow/block).
*/
ContentSettings.setExceptions = function(type, exceptions) {
this.getExceptionsList(type, 'normal').setExceptions(exceptions);
@@ -205,9 +218,9 @@ cr.define('options', function() {
* Initializes an exceptions list.
* @param {string} type The content type that we are setting exceptions for.
- * @param {Array} exceptions An array of pairs, where the first element of
- * each pair is the filter string, and the second is the setting
- * (allow/block).
+ * @param {Array.<options.Exception>} exceptions An array of pairs, where the
+ * first element of each pair is the filter string, and the second is the
+ * setting (allow/block).
*/
ContentSettings.setExceptions = function(type, exceptions) {

Powered by Google App Engine
This is Rietveld 408576698